@@ -1,17 +1,18 @@
-from peewee import Model
+from peewee import Model, EXCLUDED
 
 
 class BaseModel(Model):
-    def bulk_save(self, data: list):
-        for row in data:
-            if type(row) is not list and type(row) is not dict:
-                row = row.__data__
-            self.save(row)
+    def bulk_save(self, rows: list):
+        conflict_fields = self.get_model_indexes()
+        update_fields = self.get_excluded_fields()
 
-    def save(self, row):
-        if not row:
-            return
+        self.model.insert_many(rows).on_conflict(
+            action=None,
+            conflict_target=conflict_fields,
+            update=update_fields,
+        ).execute()
 
+    def save_or_update(self, row):
         conflict_fields = self.get_model_indexes()
         row = self.match_schema(row)
         update_data = self.get_update_data(dict(row))
@@ -42,6 +43,19 @@ class BaseModel(Model):
 
         return row
 
+    def get_excluded_fields(self):
+        fields = self.get_model_fields()
+        indexes = self.get_model_indexes()
+
+        fields_set = set(fields.keys())
+        indexes_set = set(indexes)
+
+        fields_without_indexes = list(fields_set - indexes_set)
+
+        result = {field: getattr(EXCLUDED, field) for field in fields_without_indexes}
+
+        return result
+
     # Get model fields list
     def get_schema(self):
         schema = list(self._meta.fields)
@@ -52,3 +66,8 @@ class BaseModel(Model):
         indexes = list(self._meta.indexes)
 
         return indexes[0][0] if indexes else []
+
+    def get_model_fields(self):
+        fields = self._meta.fields
+
+        return fields
